package form.io;

import form.data.*;
import java.awt.*;
import java.awt.event.*;
import java.util.StringTokenizer;
import java.io.*;

public class FtpDialog extends Dialog implements MouseListener , ActionListener{

public static final int OPEN = 0;
public static final int SAVE = 1;

BufferedReader inReader = null;
PrintWriter    outWriter= null;
TextField path = new TextField();
TextArea  folders = new TextArea(10,10);
TextArea  files   = new TextArea(10,20);
TextField filename= new TextField();
Button    ok      = new Button("OK");
Button    cancel  = new Button("Cancel");
int openOrSave = 0;

FtpClient f = null;

void connect(String user, String pass, String host){
   NameAndPass np = new NameAndPass();
   np.setName(user);
   np.setPass(pass);
   np.setHost(host);
   connect(np);
}

void connect(){
   NameAndPass np = new NameAndPass();
   connect(np);
}

void connect(NameAndPass np){
   np.show();
   try{
      f = new FtpClient(np.getHost());
      System.out.print(f.getResponseString());
      f.login(np.getName(),np.getPass());
      System.out.print(f.getResponseString());
   } catch(Exception e){e.printStackTrace();}
}

void update(){

  try{
      folders.setText("");
      files.setText("");
      updatePWD();
      updateDirs();
 } catch(Exception e){e.printStackTrace();}
}

void updatePWD(){
 try{
  f.pwd();
  StringTokenizer s = new StringTokenizer(f.getResponseString(),"\"");
  s.nextToken();
  path.setText(s.nextToken());
 } catch(Exception e){e.printStackTrace();}
}

void updateDirs(){
  try{
      f.setPassive(true);
      f.ascii();  // set client to ascii mode to get text listing
      System.out.println(f.command);
      System.out.print(f.getResponseString());
 
      BufferedReader t = f.list();     // f.list gives a few more details
      System.out.println(f.command);
      System.out.print(f.getResponseString());
      while( true ) {
         String stringBuffer = t.readLine();
         if( stringBuffer == null ) break;
         parseOne(stringBuffer);
      }
      t.close();
 } catch(Exception e){e.printStackTrace();}
}

void parseOne(String line){

     //ftp list may be a fixed list
     StringTokenizer s = new StringTokenizer(line);
     //directory
     if (line.charAt(0)=='d'){
        while(s.hasMoreTokens()){
          line = s.nextToken();
        }
        folders.append(line+"\n");
      }
     //file
     if (line.charAt(0)=='-'){
        while(s.hasMoreTokens()){
          line = s.nextToken();
        }
        files.append(line+"\n");
      }
}

public static void main (String args []){
	FtpDialog fd = new FtpDialog(new Frame(),OPEN);
        fd.show();
   }

/**
*@param Frame f parent fame
*@param int type open or save operation
* FileDialog.OPEN
* FileDialog.SAVE
*/
FtpDialog(Frame f,int type){
  super(f,true);

  openOrSave = type;

  setSize(300,400);
  GridBagLayout gridbag = new GridBagLayout();
  setLayout(gridbag);

  GridBagConstraints c = new GridBagConstraints();

  c.fill = c.BOTH;
  c.insets = new Insets(4,4,4,4);
  c.weightx=1;
  c.gridwidth = 0;
  addImpl(new Label("Enter path or folder name"),c,-1);

  c.gridwidth = 0;
  addImpl(path,c,-1);

  c.gridwidth=1;
  addImpl(new Label("Folders"),c,-1);
  c.weightx = 2;
  c.gridwidth = 0;
  addImpl(new Label("Files"),c,-1);

  c.weighty=3;
  c.gridwidth = 1;
  c.weightx = 1;
  addImpl(folders,c,-1);
  c.weightx = 2;
  c.gridwidth = 0;
  addImpl(files,c,-1);

  c.weighty=1;
  addImpl(new Label("Enter file name:"),c,-1);

  addImpl(filename,c,-1);

  c.gridwidth = 1;

  addImpl(ok,c,-1);
  c.gridwidth = 0;
  addImpl(cancel,c,-1);

  files.addMouseListener(this);
  folders.addMouseListener(this);
  cancel.addActionListener(this);
  ok.addActionListener(this);
  connect();
  update();
  show();
}

public FtpDialog(String user,String pass,String host,String dir,String fname){
super(new Frame(),true);

   connect(user,pass,host);

   try {
   f.cd(dir);

   outWriter = new PrintWriter(f.putAscii(fname),true);
    }catch(Exception ex){ex.printStackTrace();}

}

  public void mouseClicked(MouseEvent e) {
        try{
    if( e.getClickCount() ==2){   
       if(e.getComponent().equals(files)){
        filename.setText(files.getSelectedText());
       }
       else if(e.getComponent().equals(folders)){
        f.cd(folders.getSelectedText());
        update();
       }
    }
  }catch (Exception ex){ex.printStackTrace();}
  }
  public void mouseEntered(MouseEvent e) {}
  public void mouseExited(MouseEvent e) {}
  public void mousePressed(MouseEvent e) {}
  public void mouseReleased(MouseEvent e) {}

  public void actionPerformed(java.awt.event.ActionEvent e){
   try{ 
   if (e.getActionCommand()=="OK"){
      if (openOrSave==OPEN){
	inReader = f.getAscii(filename.getText());
	dispose();
      }
      else if (openOrSave==SAVE){
	outWriter = new PrintWriter(f.putAscii(filename.getText()),true);
	dispose();
      }
   }
   if (e.getActionCommand()=="Cancel"){
      f.closeServer();
      System.out.println(f.command);
      System.out.print(f.getResponseString());
      dispose();
      //System.exit(1);
   }
  
 } catch(Exception ex){ex.printStackTrace();}
  }

  public void close(){
	try{
	  f.closeServer();
	}catch (IOException e){e.printStackTrace();}
  }

  public BufferedReader getReader(){
	return inReader;
  }

  public PrintWriter getWriter(String fileName){
	try{
	  outWriter = new PrintWriter(f.putAscii(filename.getText()),true);
	}catch(IOException e){e.printStackTrace();}
	return outWriter;
  }

  public PrintWriter getWriter(){
	return outWriter;
  }
}
